@@ -58,34 +58,27 @@ class DevShellAppTestCase(DevShellAppBaseTestCase):
 
             assert len(check_calls) == 1
             if sys.platform == 'win32':
-                assert check_calls[0].endswith(r'.venv\Scripts\poetry.exe update')
-                assert '\n+ .venv\\Scripts\\poetry.exe update\n' in stdout
+                assert check_calls[0].endswith(r'.venv\Scripts\poetry.exe update -v')
+                assert '\n+ .venv\\Scripts\\poetry.exe update -v\n' in stdout
             else:
-                assert check_calls[0].endswith('.venv/bin/poetry update')
-                assert '\n+ .venv/bin/poetry update\n' in stdout
+                assert check_calls[0].endswith('.venv/bin/poetry update -v')
+                assert '\n+ .venv/bin/poetry update -v\n' in stdout
 
             assert '\nPlease restart "TheDevScript.py" !\n' in stdout
         finally:
             sys.argv = origin_sys_argv
 
-    def test_do_linting(self):
-        with patch.object(subprocess, 'check_call') as check_call_mock:
-            stdout, stderr = self.execute(command='linting')
+    def test_do_pyupgrade(self):
+        stdout, stderr = self.execute(command='pyupgrade')
 
         print(stdout)
         print(stderr)
 
         assert stderr == ''
 
-        # The call will be printed:
-        if sys.platform == 'win32':
-            assert '+ .venv\\Scripts\\darker.exe --diff --check\n' in stdout
-            assert '+ .venv\\Scripts\\flake8.exe\n' in stdout
-        else:
-            assert '+ .venv/bin/darker --diff --check\n' in stdout
-            assert '+ .venv/bin/flake8\n' in stdout
-
-        check_call_mock.assert_called()
+        assert 'Run PyUpgrade' in stdout
+        assert '(min version: 3.7)' in stdout
+        assert '0 have been updated' in stdout
 
     def test_fix_code_style(self):
         with patch.object(subprocess, 'check_call') as check_call_mock:
